.. SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Shell API
=========

pypdfium2 can also be used from the command-line.


Main help
*********
``pypdfium2 help``

.. program-output:: python3 -m pypdfium2 help


Version
*******
``pypdfium2 version``

.. program-output:: python3 -m pypdfium2 version


Renderer
********
``pypdfium2 render``

.. program-output:: python3 -m pypdfium2 render


Table of Contents Reader
************************
``pypdfium2 toc``

.. program-output:: python3 -m pypdfium2 toc


Merger
******
``pypdfium2 merge``

.. program-output:: python3 -m pypdfium2 merge


Page Tiler
**********
``pypdfium2 tile``

.. program-output:: python3 -m pypdfium2 tile
